@@ -53,7 +53,7 @@ try:
     from GameSentenceMiner.util.text_log import GameLine, get_text_event, get_mined_line, get_all_lines, game_log
     from GameSentenceMiner.util import *
     from GameSentenceMiner.web import texthooking_page
-    from GameSentenceMiner.web.service import handle_texthooker_button
+    from GameSentenceMiner.web.service import handle_texthooker_button, set_get_audio_from_video_callback
     from GameSentenceMiner.web.texthooking_page import run_text_hooker_page
 except Exception as e:
     from GameSentenceMiner.util.configuration import logger, is_linux, is_windows
@@ -91,10 +91,10 @@ class VideoToAudioHandler(FileSystemEventHandler):
         selected_lines = []
         anki_card_creation_time = None
         mined_line = None
-        gsm_state.previous_replay = video_path
+        start_time = 0
+        end_time = 0
         if gsm_state.line_for_audio or gsm_state.line_for_screenshot:
-            handle_texthooker_button(
-                video_path, get_audio_from_video=VideoToAudioHandler.get_audio)
+            handle_texthooker_button(video_path)
             return
         try:
             if anki.card_queue and len(anki.card_queue) > 0:
@@ -116,6 +116,10 @@ class VideoToAudioHandler(FileSystemEventHandler):
                 if get_config().features.backfill_audio:
                     last_note = anki.get_cards_by_sentence(
                         gametext.current_line_after_regex)
+                    
+            note, last_note = anki.get_initial_card_info(last_note, selected_lines)
+            tango = last_note.get_field(
+                get_config().anki.word_field) if last_note else ''
 
             # Get Info of line mined
             line_cutoff = None
@@ -145,9 +149,6 @@ class VideoToAudioHandler(FileSystemEventHandler):
 
             if last_note:
                 logger.debug(last_note.to_json())
-            note = anki.get_initial_card_info(last_note, selected_lines)
-            tango = last_note.get_field(
-                get_config().anki.word_field) if last_note else ''
 
             if get_config().anki.sentence_audio_field and get_config().audio.enabled:
                 logger.debug("Attempting to get audio from video")
@@ -201,16 +202,14 @@ class VideoToAudioHandler(FileSystemEventHandler):
             logger.debug(
                 f"Some error was hit catching to allow further work to be done: {e}", exc_info=True)
             notification.send_error_no_anki_update()
-        finally:
-            if get_config().paths.remove_video and video_path and not skip_delete:
-                try:
-                    if os.path.exists(video_path):
-                        logger.debug(f"Removing video: {video_path}")
-                        os.remove(video_path)
-                except Exception as e:
-                    logger.error(
-                        f"Error removing video file {video_path}: {e}", exc_info=True)
-            pass
+        if get_config().paths.remove_video and video_path and not skip_delete:
+            try:
+                if os.path.exists(video_path):
+                    logger.debug(f"Removing video: {video_path}")
+                    os.remove(video_path)
+            except Exception as e:
+                logger.error(
+                    f"Error removing video file {video_path}: {e}", exc_info=True)
 
     @staticmethod
     def get_audio(game_line, next_line_time, video_path, anki_card_creation_time=None, temporary=False, timing_only=False, mined_line=None):
@@ -525,6 +524,7 @@ def handle_exit():
 def initialize(reloading=False):
     global obs_process
     if not reloading:
+        get_temporary_directory(delete=True)
         if is_windows():
             download_obs_if_needed()
             download_ffmpeg_if_needed()
@@ -538,6 +538,7 @@ def initialize(reloading=False):
         # gametext.start_text_monitor()
         os.makedirs(get_config().paths.folder_to_watch, exist_ok=True)
         os.makedirs(get_config().paths.output_folder, exist_ok=True)
+        set_get_audio_from_video_callback(VideoToAudioHandler.get_audio)
     initial_checks()
     register_websocket_message_handler(handle_websocket_message)
     # if get_config().vad.do_vad_postprocessing:
@@ -633,7 +634,7 @@ async def register_scene_switcher_callback():
 
 
 async def run_test_code():
-    if get_config().wip.overlay_websocket_port and get_config().wip.overlay_websocket_send:
+    if get_config().overlay.websocket_port:
         boxes = await gametext.find_box_for_sentence("ちぇっ少しなの？")
         if boxes:
             await texthooking_page.send_word_coordinates_to_overlay(boxes)
