@@ -22,7 +22,7 @@ from GameSentenceMiner.util.electron_config import *
 from GameSentenceMiner.ocr.ss_picker import ScreenCropper
 from GameSentenceMiner.owocr.owocr.run import TextFiltering
 from GameSentenceMiner.util.configuration import get_config, get_app_directory, get_temporary_directory
-from GameSentenceMiner.ocr.gsm_ocr_config import OCRConfig, set_dpi_awareness, get_window, get_ocr_config_path
+from GameSentenceMiner.ocr.gsm_ocr_config import OCRConfig, has_config_changed, set_dpi_awareness, get_window, get_ocr_config_path
 from GameSentenceMiner.owocr.owocr import screen_coordinate_picker, run
 from GameSentenceMiner.util.gsm_utils import sanitize_filename, do_text_replacements, OCR_REPLACEMENTS_FILE
 import threading
@@ -52,7 +52,6 @@ logger.addHandler(console_handler)
 def get_ocr_config(window=None, use_window_for_config=False) -> OCRConfig:
     """Loads and updates screen capture areas from the corresponding JSON file."""
     ocr_config_dir = get_ocr_config_path()
-    obs.connect_to_obs_sync(retry=0)
     obs.update_current_game()
     if use_window_for_config and window:
         scene = sanitize_filename(window)
@@ -202,7 +201,7 @@ def do_second_ocr(ocr1_text, time, img, filtering, pre_crop_image=None, ignore_f
     try:
         orig_text, text = run.process_and_write_results(img, None, last_ocr2_result if not ignore_previous_result else None, filtering, None,
                                                         engine=get_ocr_ocr2(), furigana_filter_sensitivity=furigana_filter_sensitivity if not ignore_furigana_filter else 0)
-
+        
         if compare_ocr_results(last_sent_result, text, threshold=80):
             if text:
                 logger.info("Seems like Text we already sent, not doing anything.")
@@ -253,7 +252,8 @@ class ConfigChangeCheckThread(threading.Thread):
     def __init__(self):
         super().__init__(daemon=True)
         self.last_changes = None
-        self.callbacks = []
+        self.config_callbacks = []
+        self.area_callbacks = []
 
     def run(self):
         global ocr_config
@@ -266,20 +266,32 @@ class ConfigChangeCheckThread(threading.Thread):
                 # Only run this block after a change has occurred and then the section is stable (no change)
                 if self.last_changes is not None and not section_changed:
                     logger.info(f"Detected config changes: {self.last_changes}")
-                    for cb in self.callbacks:
+                    for cb in self.config_callbacks:
                         cb(self.last_changes)
                     if hasattr(run, 'handle_config_change'):
                         run.handle_config_change()
                     if any(c in self.last_changes for c in ('ocr1', 'ocr2', 'language', 'furigana_filter_sensitivity')):
                         reset_callback_vars()
                     self.last_changes = None
+                ocr_config_changed = has_config_changed(ocr_config)
+                if ocr_config_changed:
+                    logger.info("OCR config has changed, reloading...")
+                    ocr_config = get_ocr_config(use_window_for_config=True, window=obs.get_current_game())
+                    for cb in self.area_callbacks:
+                        cb(ocr_config)
+                    if hasattr(run, 'handle_area_config_changes'):
+                        run.handle_area_config_changes(ocr_config)
+                    reset_callback_vars()
             except Exception as e:
                 logger.debug(f"ConfigChangeCheckThread error: {e}")
             time.sleep(0.25)  # Lowered to 0.25s for more responsiveness
 
-    def add_callback(self, callback):
-        self.callbacks.append(callback)
-        
+    def add_config_callback(self, callback):
+        self.config_callbacks.append(callback)
+
+    def add_area_callback(self, callback):
+        self.area_callbacks.append(callback)
+    
 def reset_callback_vars():
     global previous_text, last_oneocr_time, text_stable_start_time, previous_orig_text, previous_img, force_stable, previous_ocr1_result, previous_text_list, last_ocr2_result
     previous_text = None
@@ -447,6 +459,17 @@ def run_oneocr(ocr_config: OCRConfig, rectangles, config_check_thread):
 
 def add_ss_hotkey(ss_hotkey="ctrl+shift+g"):
     import keyboard
+
+    def ocr_secondary_rectangles():
+        logger.info("Running secondary OCR rectangles...")
+        ocr_config = get_ocr_config()
+        img = obs.get_screenshot_PIL(compression=80, img_format="jpg")
+        ocr_config.scale_to_custom_size(img.width, img.height)
+        img = run.apply_ocr_config_to_image(img, ocr_config, is_secondary=True)
+        do_second_ocr("", datetime.now(), img, TextFiltering(lang=get_ocr_language()), ignore_furigana_filter=True, ignore_previous_result=True)
+        
+    if not manual:
+        keyboard.add_hotkey(get_ocr_manual_ocr_hotkey().lower(), ocr_secondary_rectangles)
     secret_ss_hotkey = "F14"
     filtering = TextFiltering(lang=get_ocr_language())
     cropper = ScreenCropper()
@@ -544,6 +567,8 @@ if __name__ == "__main__":
         use_window_for_config = args.use_window_for_config
         keep_newline = args.keep_newline
         obs_ocr = args.obs_ocr
+        
+        obs.connect_to_obs_sync(retry=0)
     
         # Start config change checker thread
         config_check_thread = ConfigChangeCheckThread()
